sqltriples.Adapters.pysqlite2Adapter

Package sqltriples :: Module Adapters :: Class pysqlite2Adapter |
[show private | hide private]
[frames | no frames]

## Class pysqlite2Adapter

    Adapter --+
              |
             pysqlite2Adapter

Method Summary
| `query_next_bnode_id(self, cursor, sequence_name)`
Inherited from Adapter
| ``__init__`(self, connection)`
| ``delete_index`(self, cursor, table_name)`
| ``delete_sequence`(self, cursor, sequence_name)`
| ``delete_table`(self, cursor, table_name)`
| ``init_index`(self, cursor, table_name)`
| ``init_sequence`(self, cursor, sequence_name)`
| ``init_table`(self, cursor, table_name)`
| ``_pmark`(self, i)`
| ``_present`(self, values)`

Class Variable Summary
`str` | `paramstyle` = `'qmark'`
`str` | `_delete_index_object` = `'drop index %s_object'`
`str` | `_delete_index_predicate` = `'drop index %s_predicate'`
`str` | `_delete_index_subject` = `'drop index %s_subject'`
`str` | `_delete_table` = `'drop table %s'`
`str` | `_init_index_object` = `'create index %s_object on %s(objec...`
`str` | `_init_index_predicate` = `'create index %s_predicate on %s...`
`str` | `_init_index_subject` = `'create index %s_subject on %s(sub...`
`str` | `_init_table` = `'\n create table %s (\n ...`
Inherited from Adapter
`int` | `supports_in_tuples` = 0
`dict` | `_paramdict` = `{'named': 1, 'format': 0, 'pyformat': 1, 'n...`

Class Variable Details

    ### paramstyle Type: `str` Value:
        'qmark'

    ### _delete_index_object Type: `str` Value:
        'drop index %s_object'

    ### _delete_index_predicate Type: `str` Value:
        'drop index %s_predicate'

    ### _delete_index_subject Type: `str` Value:
        'drop index %s_subject'

    ### _delete_table Type: `str` Value:
        'drop table %s'

    ### _init_index_object Type: `str` Value:
        'create index %s_object on %s(object)'

    ### _init_index_predicate Type: `str` Value:
        'create index %s_predicate on %s(predicate)'

    ### _init_index_subject Type: `str` Value:
        'create index %s_subject on %s(subject)'

    ### _init_table Type: `str` Value:
        '''
                create table %s (
                    subject text, predicate text, object text,
                    subject_type char, object_type char,
                    context text,
                    primary key(subject, subject_type, predicate, object, obje\
        ct_type, context)
                )
        ...

Generated by Epydoc 2.1 on Sat Jul 7 23:24:47 2007 | http://epydoc.sf.net